@@ -114,7 +114,6 @@ def generate_network(n_of_families, use_probabilities):
 
     number_of_nodes = np.sum(family_distribution)
 
-
     # frequent contact distribution
     frequent_contact_distribution = np.random.normal(12, 3, n_of_families).round().astype(int)
     frequent_contact_distribution = list(frequent_contact_distribution[frequent_contact_distribution >= 0])
@@ -122,7 +121,6 @@ def generate_network(n_of_families, use_probabilities):
     # refine to have sum = node number
     frequent_contact_distribution = fix_distribution_node_number(frequent_contact_distribution, number_of_nodes)
 
-
     # occasional contact distribution
     occasional_contact_distribution = np.random.normal(24, 6, n_of_families).round().astype(int)
     occasional_contact_distribution = list(occasional_contact_distribution[occasional_contact_distribution >= 0])
@@ -260,7 +258,7 @@ def compute_TR(G, R_0, infection_duration, incubation_days):
     avr_deg = list()
     # compute average weighted degree on 20 steps
     for i in range (20):
-        step(G, i, 0, 0, 0, 0, 0, 0, False, list(), 0, "Random", 0, 0, False, 0.5, 0.5)
+        step(G, i, 0, 0, 0, 0, 0, 0, False, list(), 0, "Random", 0, 0, False, 0, 0, 0)
 
         degrees = G.strength(list(range(len(G.vs))), weights = "weight")
         avr_deg.append(sum(degrees) / len(degrees))
